@@ -3,23 +3,21 @@ from .helpers.std import Std
 
 
 class HentaiFoxCom(Provider, Std):
-    __local_storage = None
     _idx_re = r'/g(?:allery)?/(\d+)'
     _url_str = '{}/gallery/{}/'
     _name_selector = '.info h1'
+    _archive_prefix = 'HentaiFox_'
 
     def get_archive_name(self) -> str:
         return self.get_chapter_index()
 
     def get_chapter_index(self) -> str:
-        return 'archive'
+        return self._archive_prefix + 'archive'
 
     def get_main_content(self):
-        if self.__local_storage is None:
-            idx = self._get_name(self._idx_re)
-            url = self._url_str.format(self.domain, idx)
-            self.__local_storage = self.http_get(url)
-        return self.__local_storage
+        idx = self._get_name(self._idx_re)
+        url = self._url_str.format(self.domain, idx)
+        return self.http_get(url)
 
     def get_manga_name(self) -> str:
         return self.text_content(self.content, self._name_selector)
@@ -37,7 +35,7 @@ class HentaiFoxCom(Provider, Std):
         return items
 
     def get_cover(self) -> str:
-        return self._cover_from_content('.cover img')
+        return self._cover_from_content('.cover img,#cover img')
 
     def book_meta(self) -> dict:
         # todo meta
